# -*- coding: utf-8 -*-

import random
import string

DEFAULT_ELASTICSEARCH_ID_SIZE = 20
CHARSET_FOR_ELASTICSEARCH_ID = string.ascii_letters + string.digits


def get_random_id(size=DEFAULT_ELASTICSEARCH_ID_SIZE):
    return ''.join(random.choice(CHARSET_FOR_ELASTICSEARCH_ID) for _ in range(size))



# -*- coding: utf-8 -*-

from setuptools import setup, find_packages

__version__ = '1.1.1'

setup(
    name='ElasticsearchMock',
    version=__version__,
    url='https://github.com/jmlw/elasticmock',
    license='MIT',
    author='Josh Wood',
    author_email='josh.m.l.wood@gmail.com',
    description='Python Elasticsearch Mock for test purposes',
    packages=find_packages(exclude=['tests']),
    zip_safe=False,
    include_package_data=True,
    platforms='any',
    install_requires=[
        'elasticsearch>=5.0.0,<6.0.0',
        'mock==1.0.1'
    ],
    classifiers=[
        'Environment :: Web Environment',
        'Intended Audience :: Developers',
        'Operating System :: OS Independent',
        'Programming Language :: Python',
        'Topic :: Software Development :: Libraries :: Python Modules'
    ]
)
